@@ -1,8 +1,11 @@
 #' Compute the optimal encoding for each state
 #'
-#' Compute the optimal encoding for categorical functional data using an extension of the multiple correspondence analysis to a stochastic process.
+#' Compute the optimal encoding for categorical functional data using an extension of the multiple correspondence analysis
+#' to a stochastic process.
 #'
-#' @param data data.frame containing \code{id}, id of the trajectory, \code{time}, time at which a change occurs and \code{state}, associated state. All individuals must begin at the same time T0 and end at the same time Tmax (use \code{\link{cut_data}}).
+#' @param data data.frame containing \code{id}, id of the trajectory, \code{time}, time at which a change occurs and
+#' \code{state}, associated state. All individuals must begin at the same time T0 and end at the same time Tmax
+#' (use \code{\link{cut_data}}).
 #' @param basisobj basis created using the \code{fda} package (cf. \code{\link{create.basis}}).
 #' @param computeCI if TRUE, perform a bootstrap to estimate the variance of encoding functions coefficients
 #' @param nBootstrap number of bootstrap samples
@@ -70,14 +73,21 @@
 #'
 #' @references
 #' \itemize{
-#'   \item Deville J.C. (1982) Analyse de données chronologiques qualitatives : comment analyser des calendriers ?, Annales de l'INSEE, No 45, p. 45-104.
-#'   \item Deville J.C. et  Saporta G. (1980) Analyse harmonique qualitative, DIDAY et al. (editors), Data Analysis and Informatics, North Holland, p. 375-389.
-#'   \item Saporta G. (1981) Méthodes exploratoires d'analyse de données temporelles, Cahiers du B.U.R.O, Université Pierre et Marie Curie, 37-38, Paris.
+#'   \item Deville J.C. (1982) Analyse de données chronologiques qualitatives : comment analyser des calendriers ?,
+#' Annales de l'INSEE, No 45, p. 45-104.
+#'   \item Deville J.C. et  Saporta G. (1980) Analyse harmonique qualitative, DIDAY et al. (editors), Data Analysis and
+#' Informatics, North Holland, p. 375-389.
+#'   \item Saporta G. (1981) Méthodes exploratoires d'analyse de données temporelles, Cahiers du B.U.R.O, Université
+#' Pierre et Marie Curie, 37-38, Paris.
+#'   \item Preda C, Grimonprez Q, Vandewalle V. Categorical Functional Data Analysis. The cfda R Package.
+#' Mathematics. 2021; 9(23):3074. https://doi.org/10.3390/math9233074
 #' }
 #'
+#' @family encoding functions
 #'
 #' @export
-compute_optimal_encoding <- function(data, basisobj, computeCI = TRUE, nBootstrap = 50, propBootstrap = 1, nCores = max(1, ceiling(detectCores() / 2)), verbose = TRUE, ...) {
+compute_optimal_encoding <- function(data, basisobj, computeCI = TRUE, nBootstrap = 50, propBootstrap = 1,
+                                     nCores = max(1, ceiling(detectCores() / 2)), verbose = TRUE, ...) {
   t1 <- proc.time()
   ## check parameters
   checkData(data)
@@ -151,7 +161,8 @@ compute_optimal_encoding <- function(data, basisobj, computeCI = TRUE, nBootstra
       out <- c(fullEncoding, list(V = V, basisobj = basisobj, label = label, pt = pt))
     } else {
       varAlpha <- computeVarianceAlpha(bootEncoding, K, nBasis)
-      out <- c(fullEncoding, list(V = V, basisobj = basisobj, label = label, pt = pt, bootstrap = bootEncoding, varAlpha = varAlpha))
+      out <- c(fullEncoding, list(V = V, basisobj = basisobj, label = label, pt = pt,
+                                  bootstrap = bootEncoding, varAlpha = varAlpha))
     }
   } else {
     out <- c(fullEncoding, list(V = V, basisobj = basisobj, label = label, pt = pt))
@@ -334,7 +345,7 @@ compute_Uxij <- function(x, phi, K, ...) {
   for (u in seq_len(nrow(x) - 1))
   {
     state <- x$state[u]
-    for (i in 1:nBasis)
+    for (i in seq_len(nBasis))
     {
       for (j in i:nBasis) # symmetry between i and j
       {
